//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Frontend.rc
//
#define IDD_FRONTEND_DIALOG             102
#define IDP_SOCKETS_INIT_FAILED         103
#define IDR_MAINFRAME                   128
#define IDD_DIALOG1                     129
#define IDD_DIALOG2                     130
#define IDD_DIALOG3                     131
#define IDD_DIALOG4                     132
#define IDI_ICON1                       132
#define IDR_241                         138
#define IDI_ICON3                       141
#define IDR_TRAYMENU                    141
#define IDI_ICON2                       142
#define IDC_TAB1                        1000
#define IDC_BUTTON1                     1001
#define IDC_EDIT1                       1003
#define IDC_BUTTON2                     1004
#define IDC_EDIT2                       1004
#define IDC_EDIT3                       1005
#define IDC_BUTTON3                     1006
#define IDC_EDIT4                       1006
#define IDC_EDIT5                       1007
#define IDC_LIST1                       1008
#define IDC_SLIDER2                     1009
#define IDC_TEXT1                       1010
#define IDC_EDIT6                       1011
#define IDC_EDIT7                       1012
#define IDC_CHECK1                      1013
#define IDC_CHECK2                      1014
#define IDC_EDIT9                       1015
#define IDC_CHECK3                      1016
#define IDC_BUTTON4                     1017
#define IDC_BUTTON5                     1018
#define IDC_CHECK4                      1019
#define IDC_EDIT10                      1020
#define IDC_EDIT11                      1021
#define IDC_EDIT8                       1022
#define IDC_CHECK5                      1022
#define IDC_EDIT12                      1023
#define IDC_EDIT13                      1024
#define IDC_LIST4                       1025
#define IDC_LIST5                       1026
#define IDC_EDIT15                      1026
#define IDC_LIST6                       1027
#define IDC_RADIO1                      1029
#define IDC_RADIO2                      1030
#define IDC_COMBO1                      1031
#define IDC_COMBO3                      1035
#define IDM_START                       32773
#define IDM_STOP                        32774
#define IDM_WINDOW                      32775
#define IDM_SETTINGS                    32776
#define IDM_OUTPUT                      32777
#define IDM_EXIT                        32778

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        143
#define _APS_NEXT_COMMAND_VALUE         32779
#define _APS_NEXT_CONTROL_VALUE         1036
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

/*
 * Local Variables:
 * c-basic-offset: 2
 * indent-tabs-mode: nil
 * End:
 */
